# Architecture Overview

Graphite is an open-source framework designed for building *domain-specific* AI assistants through composable agentic workflows. We provide a highly extensible platform that empowers AI engineers to create custom workflows tailored to their specific business domains.

In this documentation, we'll explore Graphite's architecture and each component in detail, while adhering to our core design philosophy: each component should only know what it needs to know. This principle of minimal coupling enables the flexibility and modularity that makes Graphite powerful.

## Architecture

Below is an overview of the Graphite architecture. In the following sections, we'll break down each component and explore them in detail.

![graphite_architecture](../static/graphite_architecture.png)
